/*
	Figure 3.2
	England and Wales breast cancer data.
	Show survival and hazard functions.
*/
version 11.0
set scheme sj
set more off
clear
use EW_breast2

stset survtime, failure(dead = 1) exit(time 5) id(ident)
// Survival - KM
sts graph, xtitle("Time from diagnosis (years)") ytitle("Survival function") ///
 ci legend(off) name(g1, replace)

// Survival - stpm2 with 2 knots
stpm2, df(3) scale(hazard) nolog
predict sstpm, survival ci
preserve
qui bysort _t: drop if _n > 1
graph twoway (rarea sstpm_lci sstpm_uci _t, pstyle(ci) sort) ///
 (line sstpm _t, sort lpattern(l)) ///
 , yscale(r(0 1)) ylabel(0(.25)1) ///
 xtitle("Time from diagnosis (years)") ytitle("Survival function") ///
 title("Survival curve from stpm2") ///
 legend(off) name(g2, replace)
restore

// Hazard - kernel smoothing with Epanichnikov kernel
sts graph, hazard kernel(epan2) ci ///
 yscale(r(0 .1)) ylabel(0(.02).1) ///
 xtitle("Time from diagnosis (years)") ytitle("Hazard function") ///
 legend(off) name(g3, replace)

// Hazard - stpm2 with 2 knots
stpm2, df(3) scale(hazard) nolog
predict hstpm, hazard ci
preserve
qui bysort _t: drop if _n > 1
graph twoway (rarea hstpm_lci hstpm_uci _t, pstyle(ci) sort) ///
 (line hstpm _t, sort lpattern(l)) ///
 , yscale(r(0 .1)) ylabel(0(.02).1) ///
 xtitle("Time from diagnosis (years)") ytitle("Hazard function") ///
 title("Hazard function from stpm2") ///
 legend(off) name(g4, replace)
restore
graph combine g1 g2 g3 g4, imargin(small)
set more on
