/*
	Figure 3.1
	Show survival and hazard functions for Rotterdam data.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Survival - KM
sts graph, xtitle("Relapse free interval, yr") ytitle("Survival function") ///
 ci xla(0(2)10) legend(off) name(g1, replace)  ylabel(,angle(h) format(%3.2f)) 

// Survival - stpm2 with 2 knots
stpm2, df(3) scale(h) nolog
predict sstpm, survival ci
graph twoway (rarea sstpm_lci sstpm_uci _t, pstyle(ci) sort) ///
 (line sstpm _t, sort clp(l)) ///
 , yscale(r(0 1)) ylabel(0(.25)1,angle(h) format(%3.2f)) ///
 xtitle("Relapse free interval, yr") ytitle("Survival function") ///
 title("Survival curve from stpm2") ///
 legend(off) name(g2, replace)

// Hazard - kernel smoothing with Epanichnikov kernel
sts graph, hazard kernel(epan2) ci ///
 yscale(log) ylabel(0.02 0.05 0.1  0.2 0.5, angle(h)) ///
 xtitle("Relapse free interval, yr") ytitle("Hazard function") ///
 legend(off) name(g3, replace) 

// Hazard - stpm2 with 2 knots
stpm2, df(3) scale(h) nolog
predict hstpm, hazard ci
graph twoway (rarea hstpm_lci hstpm_uci _t, pstyle(ci) sort) ///
 (line hstpm _t, sort clp(l)) ///
 , yscale(log) ylabel(0.02 0.05 0.1  0.2 0.5, angle(h)) //////
 xtitle("Relapse free interval, yr") ytitle("Hazard function") ///
 title("Hazard function from stpm2") ///
 legend(off) name(g4, replace)

graph combine g1 g2 g3 g4, imargin(small) nocopies
set more on
