/*
	Figure 5.3
	Rotterdam data. Compare NelsonAalen estimator of cumulative hazard
	function with spline-based model and Weibull model.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

sts gen Hna = na
sts gen Hlb = lb(na)
sts gen Hub = ub(na)
sts gen S = s
sts gen Slb = lb(s)
sts gen Sub = ub(s)

stpm2, scale(hazard) df(3) nolog
predict Hstpm, cumhaz
predict Sstpm, survival

// Weibull
streg, distribution(weibull)
predict Sweib, surv
gen Hweib = -ln(Sweib)

quietly bysort _t: drop if _n>1

twoway (rarea Hlb Hub _t, pstyle(ci) sort) ///
 (line Hna Hstpm Hweib _t if Hna > 0, sort lpattern(l - _.)) ///
 , leg(off) ytitle("Cumulative hazard function (log scale)", size(large)) xtitle("") ///
 xsca(log)ysca(log) yla(.0001 .001 .01 .1 1, angle(horizontal) format(%6.4f)) ///
 xlabel(0.1 0.2 0.5 1 2 5 10) name(g1, replace)

twoway (rarea Slb Sub _t, pstyle(ci) sort) ///
 (line S Sstpm Sweib _t, sort lpattern(l - _.)) ///
 , leg(off) ytitle("Survival function", size(large)) ///
 xtitle("") ylab(, angle(h) format(%4.1f)) name(g2, replace)

graph combine g1 g2, b2title("Years from surgery")
set more on
