/*
	Chapter 6
	Figure 6.8
	Plot 10, 50 and 90th centilea of survival time versus prognostic index.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model and predict prognostic index
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
predict xb, xbnobaseline
quietly stpm2 xb, scale(odds) df(2)

// Predict 3 centiles of survival time at different centiles of prog. index
foreach thing in C10 C50 C90 xbval {
	quietly gen `thing' = .
}
local i 0
forvalues j = 5 (5) 95 {
	quietly centile xb, centile(`j')
	local xb_cent = r(c_1)
	local ++i
	quietly replace xbval = `xb_cent' in `i'
	forvalues k = 10 (40) 90 {
		predict c`k', centile(`k') at(xb `xb_cent')
		quietly summarize c`k'
		quietly replace C`k' = r(mean) in `i'
		drop c`k'
	}
}

// Distinguish predicted median above observed follow-up time (10 years)
gen C50a = C50 if C50 > 10
replace C50 = . if C50 > 10
line C10 C50 C90 C50a xbval, sort lpattern(l - -. -) lwidth(medthick ..) ///
 ylabel(1 2 5 10, angle(h)) yscale(log) yline(10) ///
 ytitle("Years since surgery (log scale)") ///
 xtitle("Prognostic index") xlabel(-2.5 (0.5) 0.5, format(%4.1f)) ///
 lcolor(gs2 gs2 gs12 gs12) legend(order(1 2 3) label(1 "10th centile") ///
 label(2 "50th centile") label(3 "90th centile") ring(0) pos(1) col(1))
set more on
