/*
	Chapter 6
	Figure 6.5
	Impute censored survival times and plot smooth ln(t) against nodes.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Compute adjustment values for covariates other than nodes
local at _Isize_2 1 _Isize_3 0 grade 3 chemo 0 hormon 0
foreach var of varlist age pr_1 {
	quietly centile `var', centile(50)
	local at `at' `var' `=r(c_1)'
}

// Fit Royston-Parmar model
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)

// Predict survival curves for different values of nodes
local j 0
foreach n of num 0 1 2 3 5 10 25 {
	local nn = exp(-0.24 * `n')
	local ++j
	predict s`j', survival at(enodes_1 `nn' `at')
}

// Plot
quietly bysort _t: drop if _n > 1
line s1 s2 s3 s4 s5 s6 s7 _t, sort xtitle("Years since surgery") ///
 ytitle("S(t)") lpattern(l ..) legend(off) ///
 ylabel(0(0.2)1, angle(h) format(%4.1f)) ///
 text(.55 10 "0 nodes", place(w)) ///
 text(.42 10 "1 node", place(w)) ///
 text(.32 10 "2 nodes", place(w)) ///
 text(.25 10 "3 nodes", place(w)) ///
 text(.18 10 "5 nodes", place(w)) ///
 text(.13 10 "10 nodes", place(w)) ///
 text(.05 10 "25 nodes", place(w))
set more on
