/*
	Chapter 7
	Cox with model time-dependent effects.
	Includes figures 7.1, 7.2, 7.3
*/
version 11.0
clear
use ew_breast_ch7
stset survtime, failure(dead==1) exit(time 5) id(ident)

// Figure 7.1:  Kaplan-Meier graph
sts graph, by(dep5) ///
	risktable(,rowtitle("Least Deprived    ") group(#1)) ///
	risktable(,rowtitle("Most Deprived    ") group(#2)) ///
	ytitle(Proportion Alive) ///
	xtitle(Years from Diagnosis) ///
	legend(order(1 "Least Deprived" 2 "Most Deprived") ring(0) pos(5) col(1)) ///
	ylabel(,angle(h))
	

/* Cox model */	
clear
use ew_breast_ch7
stset survtime, failure(dead==1) exit(time 5) id(ident)
stcox dep5,  nolog noshow

// Figure 7.2: scaled Schoenfeld residual Plot
predict sca1, scaledsch
running sca1 _t if _d == 1, gen(smooth_sca) gense(smooth_sca_se) nodraw
gen smooth_esca = exp(smooth_sca)
gen smooth_esca_lci = exp(smooth_sca - 1.96*smooth_sca_se)
gen smooth_esca_uci = exp(smooth_sca + 1.96*smooth_sca_se)
local beta = exp(_b[dep5])
twoway (rarea smooth_esca_lci smooth_esca_uci _t, pstyle(ci) sort) ///
	(line smooth_esca _t, sort lpattern(solid)) ///
	(function y = 1, lpattern(shortdash) range(_t)) ///
	(function y = `beta', lpattern(shortdash) range(_t)) ///
	, legend(off) ///
	ytitle("Exponentiated Scaled Schoenfeld Residual") ///
	xtitle("Years from Diagnosis") ///
	ylabel(,angle(h)) yscale(log) scheme(sj)

	
/* Schoenfeld residual test */	
estat phtest, log		

/* Non-proportional hazards by splitting the time-scale */
stsplit sptime, at(1 2)
stcox i1.dep5#ibn.sptime, nolog noshow		

local hr1 = exp(_b[1.dep5#0.sptime])
local hr2 = exp(_b[1.dep5#1.sptime])
local hr3 = exp(_b[1.dep5#2.sptime])
local hr1_lci = exp(_b[1.dep5#0.sptime] - 1.96*_se[1.dep5#0.sptime])
local hr1_uci = exp(_b[1.dep5#0.sptime] + 1.96*_se[1.dep5#0.sptime])
local hr2_lci = exp(_b[1.dep5#1.sptime] - 1.96*_se[1.dep5#1.sptime])
local hr2_uci = exp(_b[1.dep5#1.sptime] + 1.96*_se[1.dep5#1.sptime])
local hr3_lci = exp(_b[1.dep5#2.sptime] - 1.96*_se[1.dep5#2.sptime])
local hr3_uci = exp(_b[1.dep5#2.sptime] + 1.96*_se[1.dep5#2.sptime])


/* likelihood ratio test */
estimates store nonph

stcox dep5
estimates store ph
lrtest ph nonph
	
/* stjoin the data and allow hr to be function of log time */
drop sptime
stjoin
stcox dep5, tvc(dep5) texp(ln(_t)) nohr nolog noshow

range temptime 0.03 5 200	
predictnl lhr = [main][dep5] + [tvc][dep5]*ln(temptime), ci(lhr_lci lhr_uci)
gen hr = exp(lhr)
gen hr_lci = exp(lhr_lci)
gen hr_uci = exp(lhr_uci)

// Figure 7.3: time-dependent hazard ratio for deprivation group
twoway		(rarea	hr_lci hr_uci temptime, sort pstyle(ci)) ///
			(line hr temptime, sort lwidth(thick) lcolor(black) lpattern(solid)) ///
			(function y = `hr1', range(0 1) lwidth(thick) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr2', range(1 2) lwidth(thick) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr3', range(2 5) lwidth(thick) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr1_lci', range(0 1) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr2_lci', range(1 2) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr3_lci', range(2 5) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr1_uci', range(0 1) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr2_uci', range(1 2) lpattern(dash) lcolor(gs7)) ///
			(function y = `hr3_uci', range(2 5) lpattern(dash) lcolor(gs7)) ///
			, legend(off) ///
			ylabel(,angle(h)) ///
			ytitle("Hazard Ratio") ///
			xtitle("Years from Diagnosis") ///
			yscale(log)

