/*
	Chapter 7
	Illustration of different hazard ratios when there is more 
	than one time-dependent effect in stpm2 models.
	Includes figure 7.19
*/
version 11.0
set more off
clear
use ew_breast_ch7

stset survtime, failure(dead==1) exit(time 5) id(ident)
range temptime 0.003 5 200

gen byte yr8990 = year(datediag)>=1989
stpm2 dep5 yr8990, scale(hazard) df(5) nolog ///
	tvc(dep5 yr8990) dftvc(3) 
predict hr_dep5_early, timevar(temptime) ///
	hrnum(dep5 1 yr8990 0) hrdenom(dep5 0 yr8990 0) ci
predict hr_dep5_late, timevar(temptime) ///
	hrnum(dep5 1 yr8990 1) hrdenom(dep5 0 yr8990 1) ci

// Figure 7.19
twoway          (line hr_dep5_early_lci hr_dep5_early_uci hr_dep5_early temptime ///
                        if temptime>0.1, ///
                lwidth(medium medium thick) lpattern(solid solid solid)) ///
                        (line hr_dep5_late_lci hr_dep5_late_uci hr_dep5_late temptime ///
                        if temptime>0.1, ///
                                lwidth(medium medium thick) lpattern(dash dash dash)) ///
                        , legend(order(1 "Diagnosed 1986-1988" 4 "Diagnosed 1989-1990") ///
                                        pos(1) col(1) ring(0)) ///
                        scheme(sj) ///
                        xtitle("Years from diagnosis") ///
                        ytitle("Hazard ratio") ///
                        yscale(log) ///
                        ylabel(, angle(h))
set more on
