/*
	Chapter 9
	Crude probability estimates
	Includes Figures 9.16, 9.17, 9.18
	!! Needs -grc1leg- to be installed from Vince Wiggins' website
*/
version 11.0
set scheme sj
set more off
clear
use EW_breast

stset survtime, failure(dead==1) exit(time 5) id(ident)

gen age = int(min(agediag + _t,99))
gen year = int(year(datediag) + _t)
merge m:1 sex region dep year age using popmort_uk ///
	,keepusing(rate) keep(match) 

rcsgen agediag, gen(agercs) df(4) orthog
global knotsage `r(knots)'
matrix Rage = r(R)
/*
	Fit a relative survival model.

	!! Note that the bhazard(rate) option is missing in the book,
	which means that the model is not a relative survival model.
	This has the knock-on effect on the estimates in Figures
	9.16-9.18 are not correct. Running this do file will give the
	correct estimates.
*/
stpm2 agercs*, scale(hazard) df(7) tvc(agercs*) dftvc(3) bhazard(rate)

drop _all
set obs 1000
range temptime 0.003 5 
gen _t = .
foreach agediag in 35 45 55 65 75 85 {
	capture drop agercs*
	tempvar a 
	gen `a' = `agediag'
	quietly rcsgen `a', knots($knotsage) gen(agercs) rmatrix(Rage)
	drop `a'
	predict s`agediag', survival timevar(temptime)
	gen netprob`agediag' = 1 - s`agediag'
}	

// Figure 9.16
twoway (line netprob* temptime) ///
		,scheme(sj) ///
		ytitle("Net probability of death due to cancer") ///
		xtitle("Time from diagnosis (years)") ///
		ylabel(0(0.2)1,format(%3.1f) angle(h)) ///
		legend(order(1 "35" 2 "45" 3 "55" 4 "65" 5 "75" 6 "85") cols(1) ring(0) pos(11) ///
		title("Age",size(*0.7)) symxsize(*0.8)) name(net, replace)
		
foreach agediag in 35 45 55 65 75 85 {
	capture drop agercs*
	tempvar a 
	gen `a' = `agediag'
	quietly rcsgen `a', knots($knotsage) gen(agercs) rmatrix(Rage)
	drop `a'
	local atlist agercs1 `=agercs1[1]' agercs2 `=agercs2[1]' agercs3 `=agercs3[1]' agercs4 `=agercs4[1]'
	stpm2cm using popmort_uk, ///
		mergeby(sex region dep year age) maxt(5) ///
		at(`atlist') ///
		diagage(`agediag') diagyear(1990) sex(2) ///
		attyear(year) attage(age) ///
		stub(crudeprob`agediag') ///
		tgen(t`agediag') ///
		mergegen(region 1 dep 3) ///
		nobs(1000) survprob(survprob) 
}	

// Figure 9.17
twoway (line crudeprob*_d temptime) ///
		,scheme(sj) ///
		ytitle("Crude probability of death due to cancer") ///
		xtitle("Time from diagnosis (years)") ///
		ylabel(0(0.2)1,format(%3.1f) angle(h)) ///
		legend(order(1 "35" 2 "45" 3 "55" 4 "65" 5 "75" 6 "85") cols(1) ring(0) pos(11) ///
		title("Age",size(*0.7)) symxsize(*0.8)) name(crude, replace)

// Figure 9.18		
foreach age in 35 45 55 65 75 85  {
	gen crudeprob`age'_do = crudeprob`age'_o + crudeprob`age'_d
	twoway 	(area crudeprob`age'_d t`age', color(gs1))  ///
			(rarea crudeprob`age'_d crudeprob`age'_do t`age', color(gs5)) ///
			(area crudeprob`age'_do t`age', base(1) color(gs12)) ///
			, scheme(sj) ///
			legend(order(1 "Dead (breast cancer)" 2 "Dead (other causes)" 3 "Alive") ///
				cols(3) span size(*0.8) ///
			symxsize(*0.8)) ///
			xtitle("", size(*1.5)) ///
			ytitle("", size(*1.5)) ///
			ylabel(0(0.2)1, angle(horizontal) format(%3.1f) labsize(*1.5) grid) ///
			xlabel(,labsize(*1.5)) ///
			title("Age `age'", ring(0)) ///
			plotr(m(zero)) nodraw ///
			name(stackprob`age',replace) 
}
grc1leg stackprob35 stackprob45 stackprob55 stackprob65 stackprob75 stackprob85, ///
		nocopies scheme(lean2) ///
		name(stackprob,replace)	b1title("Years from diagnosis") ///
		l1title("Probability of death")	///
		plotregion(style(none)) graphregion(margin(0 0 0 0)) title("England")
set more on	
