/*
	Chapter 9
	Figure 9.6
	Density function and normal plot for the Rotterdam data using a
	probit(2) model.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

sts gen S = s
sts gen Slb = lb(s)
sts gen Sub = ub(s)
foreach thing in S Slb Sub {
	gen Z`thing' = -invnormal(`thing')
}
stpm2, scale(normal) df(2)
predict d, density
predict z, normal

// Get density for log t
replace d = d * _t
quietly bysort _t: drop if _n>1
line d _t, sort xsca(log) yla(, angle(h) format(%4.2f)) ///
 xla(.1 .2 .5 1 2 5 10) xtitle("") ytitle("Density", size(large)) ///
 name(g1, replace)
twoway (rarea ZSlb ZSub _t, pstyle(ci) sort) ///
 (line ZS z _t, sort lstyle(refline ..) pstyle(p2 ..) ) ///
 , xsca(log) yla(, angle(h)) xla(.1 .2 .5 1 2 5 10) ///
 leg(off) ytitle("Probit of survival function", size(large)) xtitle("") ///
 ylab(, angle(h) format(%4.1f)) leg(off) name(g2, replace)
graph combine g1 g2, b2title("Years from surgery, log scale")
set more on
